info = {
    "name": "kl",
    "date_order": "YMD",
    "january": [
        "jan",
        "januari"
    ],
    "february": [
        "feb",
        "februari"
    ],
    "march": [
        "mar",
        "martsi"
    ],
    "april": [
        "apr",
        "aprili"
    ],
    "may": [
        "maj",
        "maji"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "juli"
    ],
    "august": [
        "aug",
        "augustusi"
    ],
    "september": [
        "sep",
        "septemberi"
    ],
    "october": [
        "okt",
        "oktoberi"
    ],
    "november": [
        "nov",
        "novemberi"
    ],
    "december": [
        "dec",
        "decemberi"
    ],
    "monday": [
        "ata",
        "ataasinngorneq"
    ],
    "tuesday": [
        "mar",
        "marlunngorneq"
    ],
    "wednesday": [
        "pin",
        "pingasunngorneq"
    ],
    "thursday": [
        "sis",
        "sisamanngorneq"
    ],
    "friday": [
        "tal",
        "tallimanngorneq"
    ],
    "saturday": [
        "arf",
        "arfininngorneq"
    ],
    "sunday": [
        "sab",
        "sabaat"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "for (\\d++[.,]?\\d*+) ulloq unnuarlu siden"
        ],
        "\\1 hour ago": [
            "for (\\d++[.,]?\\d*+) nalunaaquttap-akunnera siden"
        ],
        "\\1 minute ago": [
            "for (\\d++[.,]?\\d*+) minutsi siden"
        ],
        "\\1 month ago": [
            "for (\\d++[.,]?\\d*+) qaammat siden"
        ],
        "\\1 second ago": [
            "for (\\d++[.,]?\\d*+) sekundi siden"
        ],
        "\\1 week ago": [
            "for (\\d++[.,]?\\d*+) sapaatip-akunnera siden"
        ],
        "\\1 year ago": [
            "for (\\d++[.,]?\\d*+) ukioq siden"
        ],
        "in \\1 day": [
            "om (\\d++[.,]?\\d*+) ulloq unnuarlu"
        ],
        "in \\1 hour": [
            "om (\\d++[.,]?\\d*+) nalunaaquttap-akunnera"
        ],
        "in \\1 minute": [
            "om (\\d++[.,]?\\d*+) minutsi"
        ],
        "in \\1 month": [
            "om (\\d++[.,]?\\d*+) qaammat"
        ],
        "in \\1 second": [
            "om (\\d++[.,]?\\d*+) sekundi"
        ],
        "in \\1 week": [
            "om (\\d++[.,]?\\d*+) sapaatip-akunnera"
        ],
        "in \\1 year": [
            "om (\\d++[.,]?\\d*+) ukioq"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}



import argparse
import logging
import warnings

from .utils import clear_cache


def entrance():
    dateparser_argparse = argparse.ArgumentParser(
        description="dateparser download manager."
    )
    dateparser_argparse.add_argument(
        "--fasttext",
        type=str,
        help="[DEPRECATED] fastText is no longer supported. Please use langdetect instead.",
    )
    dateparser_argparse.add_argument(
        "--clear",
        "--clear-cache",
        help="To clear all cached models",
        action="store_true",
    )

    args = dateparser_argparse.parse_args()

    if args.clear:
        clear_cache()
        logging.info("dateparser-download: All cache deleted")

    if args.fasttext:
        warnings.warn(
            "fastText support has been removed as the library is archived and unmaintained. "
            "Please migrate to langdetect. Install with: pip install dateparser[langdetect]",
            DeprecationWarning,
            stacklevel=2,
        )
        dateparser_argparse.error(
            "fastText is no longer supported. Please use langdetect for language detection."
        )

    if not args.clear:
        dateparser_argparse.error(
            "dateparser-download: You need to specify the command (i.e.: --clear)"
        )



"""
Deprecated fastText language detection module.

This module is deprecated as the fastText library is archived and unmaintained.
Please use langdetect instead.
"""

import warnings

warnings.warn(
    "fastText support is deprecated and will be removed in a future version. "
    "The fastText library is archived and unmaintained. "
    "Please migrate to langdetect: from dateparser.custom_language_detection.langdetect import detect_languages",
    DeprecationWarning,
    stacklevel=2,
)


def detect_languages(text, confidence_threshold):
    """
    Deprecated function. FastText support has been removed.

    Args:
        text: The text to detect languages from (unused)
        confidence_threshold: Minimum confidence threshold (unused)

    Raises:
        ImportError: Always, as fastText is no longer supported.
    """
    raise ImportError(
        "fastText is no longer supported as the library is archived and unmaintained. "
        "Please use langdetect instead:\n"
        "  pip install dateparser[langdetect]\n"
        "  from dateparser.custom_language_detection.langdetect import detect_languages"
    )
